rewrite-json.node

Node protocols, types, constructors, and predicates for format-preserving JSON/JSONC representation.

Node protocols, types, constructors, and predicates for
format-preserving JSON/JSONC representation.
raw docstring

array-nodeclj

(array-node children)
source

boolean-nodeclj

(boolean-node b)
source

colon-nodeclj

(colon-node)
source

colon?clj

(colon? node)
source

comma-nodeclj

(comma-node)
source

comma?clj

(comma? node)
source

comment-nodeclj

(comment-node raw style)
source

comment?clj

(comment? node)
source

container?clj

(container? node)
source

entry-nodeclj

(entry-node child-nodes)
(entry-node key-node value-node)

Create an object entry node from a key node, value node, and optional whitespace/colon nodes between them. If only key and value are provided, a default : separator is used.

Create an object entry node from a key node, value node,
and optional whitespace/colon nodes between them.
If only key and value are provided, a default `: ` separator is used.
sourceraw docstring

entry?clj

(entry? node)
source

InnerNodecljprotocol

Extended protocol for nodes that contain children.

Extended protocol for nodes that contain children.

childrenclj

(children node)

Return the seq of child nodes.

Return the seq of child nodes.

replace-childrenclj

(replace-children node new-children)

Return a new node with replaced children.

Return a new node with replaced children.
sourceraw docstring

key-nodeclj

(key-node entry)
source

Nodecljprotocol

A single node in the JSON tree. Every node can reproduce the exact source text it was parsed from and carries a keyword tag.

A single node in the JSON tree.  Every node can reproduce the exact
source text it was parsed from and carries a keyword tag.

stringclj

(string node)

Reproduce the original source text for this node.

Reproduce the original source text for this node.

tagclj

(tag node)

Keyword identifying the node type.

Keyword identifying the node type.

valueclj

(value node)

Return a plain Clojure value (string, number, bool, nil, map, vector) or nil for non-value nodes like whitespace.

Return a plain Clojure value (string, number, bool, nil,
map, vector) or nil for non-value nodes like whitespace.
sourceraw docstring

null-nodeclj

(null-node)
source

number-nodeclj

(number-node n)
source

object-nodeclj

(object-node children)
source

printable?clj

(printable? node)
source

string-nodeclj

(string-node s)
source

value->nodeclj

(value->node x)

Convert a plain Clojure value to the corresponding node tree.

Convert a plain Clojure value to the corresponding node tree.
sourceraw docstring

value-node?clj

(value-node? node)
source

value-of-entryclj

(value-of-entry entry)
source

whitespace-nodeclj

(whitespace-node ws)
source

whitespace?clj

(whitespace? node)
source

cljdoc builds & hosts documentation for Clojure/Script libraries