Node protocols, types, constructors, and predicates for format-preserving JSON/JSONC representation.
Node protocols, types, constructors, and predicates for format-preserving JSON/JSONC representation.
(entry-node child-nodes)(entry-node key-node value-node)Create an object entry node from a key node, value node,
and optional whitespace/colon nodes between them.
If only key and value are provided, a default : separator is used.
Create an object entry node from a key node, value node, and optional whitespace/colon nodes between them. If only key and value are provided, a default `: ` separator is used.
Extended protocol for nodes that contain children.
Extended protocol for nodes that contain children.
(children node)Return the seq of child nodes.
Return the seq of child nodes.
(replace-children node new-children)Return a new node with replaced children.
Return a new node with replaced children.
A single node in the JSON tree. Every node can reproduce the exact source text it was parsed from and carries a keyword tag.
A single node in the JSON tree. Every node can reproduce the exact source text it was parsed from and carries a keyword tag.
(string node)Reproduce the original source text for this node.
Reproduce the original source text for this node.
(tag node)Keyword identifying the node type.
Keyword identifying the node type.
(value node)Return a plain Clojure value (string, number, bool, nil, map, vector) or nil for non-value nodes like whitespace.
Return a plain Clojure value (string, number, bool, nil, map, vector) or nil for non-value nodes like whitespace.
(value->node x)Convert a plain Clojure value to the corresponding node tree.
Convert a plain Clojure value to the corresponding node tree.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |